==> ldas-tools-2.0.2.tar.gz: ldas-tools-2.0.2/libraries/ldastoolsal/src/TaskTimer.cc <==
/* -*- mode: c++; c-basic-offset: 2; -*- */

#include <ldas_tools_config.h>

#include <time.h>

#include <iostream>

#include "ldastoolsal/TaskTimer.hh"

namespace LDASTools
{
  namespace AL
  {
    //-------------------------------------------------------------------
    /// Initialize the instance of the class.
    //-------------------------------------------------------------------
    Timer::
    Timer( int Seconds, int CancelSignal )
      : Task( CancelSignal ),
	m_timeout( Seconds ),
	m_err( false )
    {
    }

    //-------------------------------------------------------------------
    /// Return true if the timer expired before being cancelled.
    //-------------------------------------------------------------------
    bool Timer::
    Error( ) const
    {
      MutexLock	l( Baton( ),
		   __FILE__, __LINE__ );

      return m_err;
    }

    //-------------------------------------------------------------------
    /// For the timer task, the action is to start an interuptable
    /// sleep timer for the requested maximum time period.
    /// m_err is set to true if the sleep timer completes without
    /// any error.
    //-------------------------------------------------------------------
    void Timer::
    operator()( )
    {
      struct timespec wakeup;

      {
	MutexLock	l( Baton( ),
			   __FILE__, __LINE__ );

	wakeup.tv_sec = m_timeout;
	wakeup.tv_nsec = 0;
      }

      int err = ( nanosleep( &wakeup, NULL ) != 0 );
      {
	MutexLock	l( Baton( ),
			   __FILE__, __LINE__ );

	m_err = err;
      }
    }
  } // namespace - AL
} // namespace - LDASTools

==> ldas-tools-2.4.0.tar.gz: ldas-tools-2.4.0/libraries/ldastoolsal/src/TaskTimer.cc <==
/* -*- mode: c++; c-basic-offset: 2; -*- */

#include <ldas_tools_config.h>

#include <time.h>

#include <iostream>

#include "ldastoolsal/TaskTimer.hh"

namespace LDASTools
{
  namespace AL
  {
    //-------------------------------------------------------------------
    /// Initialize the instance of the class.
    //-------------------------------------------------------------------
    Timer::
    Timer( int Seconds, signal_type CancelSignal )
      : Task( Thread::CANCEL_BY_SIGNAL,
	      CancelSignal ),
	m_timeout( Seconds ),
	m_err( false )
    {
    }

    //-------------------------------------------------------------------
    /// Return true if the timer expired before being cancelled.
    //-------------------------------------------------------------------
    bool Timer::
    Error( ) const
    {
      MutexLock	l( Baton( ),
		   __FILE__, __LINE__ );

      return m_err;
    }

    //-------------------------------------------------------------------
    /// For the timer task, the action is to start an interuptable
    /// sleep timer for the requested maximum time period.
    /// m_err is set to true if the sleep timer completes without
    /// any error.
    //-------------------------------------------------------------------
    void Timer::
    operator()( )
    {
      struct timespec wakeup;

      {
	MutexLock	l( Baton( ),
			   __FILE__, __LINE__ );

	wakeup.tv_sec = m_timeout;
	wakeup.tv_nsec = 0;
      }

      int err = ( nanosleep( &wakeup, NULL ) != 0 );
      {
	MutexLock	l( Baton( ),
			   __FILE__, __LINE__ );

	m_err = err;
      }
    }
  } // namespace - AL
} // namespace - LDASTools
